# ifstate

*ifstate* manages host interface settings in a declarative manner relying only on *iproute2* and *ethtool*. It does **not** use nor support *Network-Manager* or *systemd-networkd*, intentionally.

It does support most *iproute2* entities.
